@@ -1,4 +1,5 @@
 use livid_desktop::{App, Settings};
+use std::path::PathBuf;
 
 fn main() {
     let a = App::new(Settings {
@@ -6,6 +7,7 @@ fn main() {
         h: 400,
         title: "My App",
         fixed: true,
+        dist_folder: PathBuf::from("examples/dist1"),
         ..Default::default()
     });
     a.run();
