@@ -11,6 +11,7 @@ livid-desktop = "0.1"
 In your main.rs
 ```rust,no_run
 use livid_desktop::{App, Settings};
+use std::path::PathBuf;
 
 fn main() {
     let a = App::new(Settings {
@@ -18,7 +19,7 @@ fn main() {
         h: 400,
         title: "My App",
         fixed: true,
-        port: 8080, // the default
+        port: "8080", // the default
         dist_folder: PathBuf::from("dist"), // the default
         ..Default::default()
     });
@@ -35,6 +36,7 @@ The dist folder should contain the index.html plus the wasm and javascript glue
     - Debian-based distros: sudo apt-get install libwebkit2gtk-4.0-dev.
     - RHEL-based distros: sudo dnf install webkit2gtk3-devel.
 */
+#![allow(clippy::needless_doctest_main)]
 
 pub mod wv;
 use livid_server::Server;
